@@ -1,2 +1,4 @@
 from .sr import pysr, get_hof, best, best_tex, best_callable, best_row
 from .feynman_problems import Problem, FeynmanProblem
+from .export_jax import sympy2jax
+from .export_torch import sympy2torch
